macro_rules! wrapped_tuple {
($wrapper:path ; $($e:expr),* $(,)?) => { ... };
($wrapper:ident! ; $($e:expr),* $(,)?) => { ... };
}Expand description
Functions identically to wrapped_list, but the list is returned as a tuple.
macro_rules! wrapped_tuple {
($wrapper:path ; $($e:expr),* $(,)?) => { ... };
($wrapper:ident! ; $($e:expr),* $(,)?) => { ... };
}Functions identically to wrapped_list, but the list is returned as a tuple.