macro_rules! wrapped_vec {
[$wrapper:path ; $($e:expr),* $(,)?] => { ... };
[$wrapper:ident! ; $($e:expr),* $(,)?] => { ... };
}Expand description
Functions identically to wrapped_list, but the list is returned as a vector.
macro_rules! wrapped_vec {
[$wrapper:path ; $($e:expr),* $(,)?] => { ... };
[$wrapper:ident! ; $($e:expr),* $(,)?] => { ... };
}Functions identically to wrapped_list, but the list is returned as a vector.